@@ -1,4 +1,4 @@
-from findpydeps import *
+from findpydeps.findpydeps import main
 import sys
 if __name__ == "__main__":
 	sys.exit(main())
\ No newline at end of file
